// src/routes/mqtt/+server.js
import * as mqtt from "mqtt";
import { writable } from "svelte/store";

// A Svelte store to hold the latest MQTT message.
// In a real application, you might want to store more data or
// use a more robust way to manage messages, but for a basic example, this works.
const latestMessage = writable("No message yet");
const devices = writable([]);

let client = null;

// Function to connect to MQTT
function connectMqtt() {
  if (client && client.connected) {
    return; // Already connected
  }

  // Replace with your MQTT broker details
  const BROKER_URL = "mqtt://kada49.it:1883"; // Example public broker
  //const BROKER_URL = "mqtt://test.mosquitto.org:1883";
  const TOPIC = "esp8266/+/data"; // Replace with your desired topic

  client = mqtt.connect(BROKER_URL);

  client.on("connect", () => {
    console.log("Connected to MQTT broker!");
    client.subscribe(TOPIC, (err) => {
      if (!err) {
        console.log(`Subscribed to topic: ${TOPIC}`);
      } else {
        console.error(`Subscription error: ${err}`);
      }
    });
  });

  client.on("message", (topic, message) => {
    const payload = message.toString();
    console.log(`Received message from topic "${topic}": ${payload}`);
    latestMessage.set(payload); // Update the Svelte store
    console.log(topic.split("/")[1]);
  });

  client.on("error", (err) => {
    console.error(`MQTT error: ${err}`);
    if (client) {
      client.end(); // Close connection on error
    }
    client = null;
    // Implement re-connection logic here if needed
  });

  client.on("close", () => {
    console.log("MQTT connection closed.");
    client = null;
    // Implement re-connection logic here if needed
  });
}

// Connect to MQTT when the server starts
connectMqtt();

/** @type {import("./$types").RequestHandler} */
export async function GET({ request }) {
  const headers = {
    "Content-Type": "text/event-stream",
    "Cache-Control": "no-cache",
    Connection: "keep-alive",
  };

  return new Response(
    new ReadableStream({
      start(controller) {
        console.log("Client connected to SSE stream.");

        const unsubscribe = latestMessage.subscribe((message) => {
          if (message !== "No message yet") {
            const data = `data: ${JSON.stringify({ message: message })}\n\n`;
            controller.enqueue(data);
          }
        });

        // Handle client disconnection
        request.signal.addEventListener("abort", () => {
          console.log("Client disconnected from SSE stream.");
          unsubscribe(); // Stop listening to store updates
          controller.close();
        });
      },
      cancel() {
        console.log("SSE stream cancelled.");
      },
    }),
    { headers },
  );
}
